@@ -21,7 +21,8 @@ import os
 import os.path
 
 PACKAGE    = "sabayon"
-VERSION    = "2.12.0"
+VERSION    = "2.12.2"
+LOCALEDIR = "/gnome/head/INSTALL/share/locale"
 DATADIR    = "/gnome/head/INSTALL/share"
 SYSCONFDIR = "/gnome/head/INSTALL/etc"
 LIBEXECDIR = "/gnome/head/INSTALL/libexec"
@@ -53,7 +54,7 @@ NOLOGIN_SHELL = "/sbin/nologin"
 SKEL_HOMEDIR  = "/etc/skel"
 
 XNEST_ARGV   = [ "/usr/X11R6/bin/Xnest", "-terminate", "-audit", "0", "-nolisten", "tcp" ]
-SESSION_ARGV = [ "/etc/X11/xdm/Xsession", "@gnome" ]
+SESSION_ARGV = [ "/etc/X11/xdm/Xsession", "gnome" ]
 USERMOD_ARGV = [ "/usr/sbin/usermod" ]
 
 PANEL_KEY_BASE = "/apps/panel"
@@ -93,7 +94,9 @@ FILES_TO_IGNORE = [
     ".gnome2/share/fonts/fonts.dir",
     ".gtkrc-1.2-gnome2*",
     ".recently-used",
-    ".xsession-errors"
+    ".xsession-errors",
+    ".local",
+    ".config"
 ]
 
 #
@@ -103,6 +106,7 @@ DIRECTORIES_TO_IGNORE = [
     ".gconf",
     ".gconf.xml.defaults",
     ".gconf.xml.mandatory",
+    ".gconf.xml.mandatory-alt",
     ".gconfd",
     ".gstreamer-0.8",
     ".metacity/sessions",
